@@ -1167,7 +1167,7 @@ def ldap_dn2path(ldap_dn, include_rdn=True):
 		return ldap_dn
 	rel_path = ldap_dn[:-(1 + len(ldap_base))]
 	rel_path = explode_dn(rel_path, True)[int(not include_rdn):]
-	return '%s:/%s' % ('.'.join(reversed(explode_dn(ldap_base, True))), '/'.join(reversed(rel_path)))
+	return '%s:/%s' % ('.'.join(explode_dn(ldap_base, True)), '/'.join(reversed(rel_path)))
 
 
 def get_module(flavor, ldap_dn, ldap_connection=None, ldap_position=None):
@@ -1544,7 +1544,7 @@ def read_syntax_choices(syn, options={}, module_search_options={}, ldap_connecti
 				elif store in obj:
 					id = obj[store]
 				elif store in obj.oldattr and obj.oldattr[store]:
-					id = obj.oldattr[store][0]
+					id = obj.oldattr[store][0].decode(*module.mapping.getEncoding(store))
 				else:
 					# no valid store object, ignore
 					MODULE.warn('LDAP_Search syntax %r: %r is no valid property for object %r - ignoring entry.' % (syntax.name, store, dn))
